package at.xaxa.ledger.ui.category.add

import android.util.Log
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.AccountBox
import androidx.compose.material.icons.filled.ArrowForward
import androidx.compose.material.icons.filled.Build
import androidx.compose.material.icons.filled.Call
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Info
import androidx.compose.material.icons.filled.LocationOn
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material.icons.filled.Notifications
import androidx.compose.material.icons.filled.Share
import androidx.compose.material.icons.filled.ShoppingCart
import androidx.compose.material.icons.filled.Warning
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.CategoryCard
import at.xaxa.ledger.ui.category.CategoryViewModel

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun addCategory(
    onButtonClick: () -> Unit,
    modifier: Modifier = Modifier,
    onCardClick: (Int) -> Unit,
    categoryViewModel: CategoryViewModel = viewModel(factory = AppViewModelProvider.Factory)
) {
    val icons = listOf(
        Icons.Filled.Call,
        Icons.Filled.Home,
        Icons.Filled.Build,
        Icons.Filled.ShoppingCart,
        Icons.Filled.Notifications,
        Icons.Filled.LocationOn,
        Icons.Filled.Delete,
        Icons.Filled.Lock,
        Icons.Filled.Info,
        Icons.Filled.Warning,
        Icons.Filled.Check,
        Icons.Filled.Close,
        Icons.Filled.AccountBox
    )
    var name by remember { mutableStateOf("") }
    var icon by remember { mutableStateOf(0) }

    val categories by categoryViewModel.categoryUiState.categories.collectAsState(initial = emptyList())
    val category = categoryViewModel.categoryUi.category
    var expanded by remember { mutableStateOf(false) }


    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        OutlinedTextField(
            value = name,
            onValueChange = { name = it },
            label = { Text("Name") },
            modifier = Modifier
                .fillMaxWidth()
        )
        OutlinedTextField(
            value = category.icon.toString(),
            onValueChange = { category.copy(icon = it.toInt()) },
            label = { Text("Icon") },
            modifier = Modifier
                .fillMaxWidth()
        )
        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(
                modifier = Modifier,
                "Add Category",
                onClick = {
                    if (name.isNotBlank()) {
                        val newCategory = CategoryEntity(
                            _id = 0,
                            categoryName = name,
                            icon = icon
                        )
                        categoryViewModel.addCategory(newCategory)
                        onButtonClick()
                    }
                }
            )
        }

        LazyColumn(
            Modifier.weight(1f)
        ) {

            items(categories) { item ->
                Column(
                    modifier = Modifier.padding(vertical = 4.dp)
                ) {
                    Log.w("KRAUSI", item.categoryName )
                    CategoryCard(
                        modifier = modifier,
                        name = item.categoryName,
                        icon = item.icon,
                        onClick = { onCardClick(item._id) }
                    )
                }
            }
        }
    }
}